@@ -1,20 +1,16 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 1997 Robey Pointer <robeypointer@gmail.com>
-  Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2009 Travis McHenry <tmchenryaz@cox.net>
+    SPDX-FileCopyrightText: 1997 Robey Pointer <robeypointer@gmail.com>
+    SPDX-FileCopyrightText: 2005 Ismail Donmez <ismail@kde.org>
+    SPDX-FileCopyrightText: 2009 Travis McHenry <tmchenryaz@cox.net>
 */
 
 #include "cipher.h"
-#include "preferences.h"
 
-#include <QDebug>
+#include "preferences.h"
+#include "konversation_log.h"
+
 #include <KLocalizedString>
 
 
@@ -25,14 +21,14 @@ namespace Konversation
     Cipher::Cipher()
     {
         m_primeNum = QCA::BigInteger("12745216229761186769575009943944198619149164746831579719941140425076456621824834322853258804883232842877311723249782818608677050956745409379781245497526069657222703636504651898833151008222772087491045206203033063108075098874712912417029101508315117935752962862335062591404043092163187352352197487303798807791605274487594646923");
-        setType("blowfish");
+        setType(QStringLiteral("blowfish"));
         if(Preferences::self()->encryptionType())
             m_cbc = true;
         else
             m_cbc = false;
     }
 
-    Cipher::Cipher(QByteArray key, QString cipherType)
+    Cipher::Cipher(const QByteArray &key, const QString &cipherType)
     {
         m_primeNum = QCA::BigInteger("12745216229761186769575009943944198619149164746831579719941140425076456621824834322853258804883232842877311723249782818608677050956745409379781245497526069657222703636504651898833151008222772087491045206203033063108075098874712912417029101508315117935752962862335062591404043092163187352352197487303798807791605274487594646923");
         setKey(key);
@@ -43,7 +39,7 @@ namespace Konversation
     {
     }
 
-    bool Cipher::setKey(QByteArray key)
+    bool Cipher::setKey(const QByteArray &key)
     {
         if(key.isEmpty())
             return false;
@@ -87,11 +83,11 @@ namespace Konversation
         {
             //if we have cbc
             if(m_cbc)
-                cipherText = cipherText.mid(5);
+                cipherText.remove(0, 5);
             //if we don't
             else
             {
-                cipherText = cipherText.mid(5);
+                cipherText.remove(0, 5);
                 pfx = "ERROR_NONECB: ";
                 error = true;
             }
@@ -110,9 +106,9 @@ namespace Konversation
             else
             {
                 if(cipherText.mid(0,4) == "+OK ")
-                    cipherText = cipherText.mid(4);
+                    cipherText.remove(0, 4);
                 else
-                    cipherText = cipherText.mid(5);
+                    cipherText.remove(0, 5);
             }
         }
         //all other cases we fail
@@ -127,7 +123,7 @@ namespace Konversation
 
             if(temp == cipherText)
             {
-                qDebug() << "Decryption from CBC Failed";
+                qCDebug(KONVERSATION_LOG) << "Decryption from CBC Failed";
                 return "ERROR: "+cipherText+' '+'\n';
             }
             else
@@ -139,7 +135,7 @@ namespace Konversation
 
             if(temp == cipherText)
             {
-                qDebug() << "Decryption from ECB Failed";
+                qCDebug(KONVERSATION_LOG) << "Decryption from ECB Failed";
                 return "ERROR: "+cipherText+' '+'\n';
             }
             else
@@ -166,12 +162,12 @@ namespace Konversation
 
         //remove leading 0
         if(publicKey.length() > 135 && publicKey.at(0) == '\0')
-            publicKey = publicKey.mid(1);
+            publicKey.remove(0, 1);
 
         return publicKey.toBase64().append('A');
     }
 
-    QByteArray Cipher::parseInitKeyX(QByteArray key)
+    QByteArray Cipher::parseInitKeyX(const QByteArray &key)
     {
         QCA::Initializer init;
 
@@ -189,7 +185,7 @@ namespace Konversation
 
         //remove leading 0
         if(publicKey.length() > 135 && publicKey.at(0) == '\0')
-            publicKey = publicKey.mid(1);
+            publicKey.remove(0, 1);
 
         QCA::DHPublicKey remotePub(group, remoteKey);
 
@@ -197,7 +193,7 @@ namespace Konversation
             return QByteArray();
 
         QByteArray sharedKey = privateKey.deriveKey(remotePub).toByteArray();
-        sharedKey = QCA::Hash("sha256").hash(sharedKey).toByteArray().toBase64();
+        sharedKey = QCA::Hash(QStringLiteral("sha256")).hash(sharedKey).toByteArray().toBase64();
 
         //remove trailing = because mircryption and fish think it's a swell idea.
         while(sharedKey.endsWith('=')) sharedKey.chop(1);
@@ -210,7 +206,7 @@ namespace Konversation
         return publicKey.toBase64().append('A');
     }
 
-    bool Cipher::parseFinishKeyX(QByteArray key)
+    bool Cipher::parseFinishKeyX(const QByteArray &key)
     {
         QCA::Initializer init;
 
@@ -229,7 +225,7 @@ namespace Konversation
             return false;
 
         QByteArray sharedKey = m_tempKey.deriveKey(remotePub).toByteArray();
-        sharedKey = QCA::Hash("sha256").hash(sharedKey).toByteArray().toBase64();
+        sharedKey = QCA::Hash(QStringLiteral("sha256")).hash(sharedKey).toByteArray().toBase64();
 
         //remove trailng = because mircryption and fish think it's a swell idea.
         while(sharedKey.endsWith('=')) sharedKey.chop(1);
@@ -242,7 +238,7 @@ namespace Konversation
     QByteArray Cipher::decryptTopic(QByteArray cipherText)
     {
         if(cipherText.mid(0,4) == "+OK ")// FiSH style topic
-            cipherText = cipherText.mid(4);
+            cipherText.remove(0, 4);
         else if(cipherText.left(5) == "«m«")
             cipherText = cipherText.mid(5,cipherText.length()-10);
         else
@@ -264,7 +260,7 @@ namespace Konversation
             cipherText = temp;
 
         if(cipherText.mid(0,2) == "@@")
-            cipherText = cipherText.mid(2);
+            cipherText.remove(0, 2);
 
         cipherText = "(e) "+cipherText;
         return cipherText;
@@ -273,7 +269,7 @@ namespace Konversation
     bool Cipher::encrypt(QByteArray& cipherText)
     {
         if (cipherText.left(3) == "+p ") //don't encode if...?
-            cipherText = cipherText.mid(3);
+            cipherText.remove(0, 3);
         else
         {
             if(m_cbc) //encode in ecb or cbc decide how to determine later
@@ -282,7 +278,7 @@ namespace Konversation
 
                 if(temp == cipherText)
                 {
-                    qDebug() << "CBC Encoding Failed";
+                    qCDebug(KONVERSATION_LOG) << "CBC Encoding Failed";
                     return false;
                 }
 
@@ -294,7 +290,7 @@ namespace Konversation
 
                 if(temp == cipherText)
                 {
-                    qDebug() << "ECB Encoding Failed";
+                    qCDebug(KONVERSATION_LOG) << "ECB Encoding Failed";
                     return false;
                 }
 
@@ -336,7 +332,7 @@ namespace Konversation
         if(direction) //send in base64
             temp2 = temp2.toBase64();
         else //cut off the 8bits of IV
-            temp2 = temp2.remove(0,8);
+            temp2.remove(0,8);
 
         return temp2;
     }
@@ -382,13 +378,13 @@ namespace Konversation
     }
 
     //Custom non RFC 2045 compliant Base64 enc/dec code for mircryption / FiSH compatibility
-    QByteArray Cipher::byteToB64(QByteArray text)
+    QByteArray Cipher::byteToB64(const QByteArray &text)
     {
         int left = 0;
         int right = 0;
         int k = -1;
         int v;
-        QString base64 = "./0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
+        QString base64 = QStringLiteral("./0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ");
         QByteArray encoded;
         while (k < (text.length() - 1)) {
             k++;
@@ -431,9 +427,9 @@ namespace Konversation
         return encoded;
     }
 
-    QByteArray Cipher::b64ToByte(QByteArray text)
+    QByteArray Cipher::b64ToByte(const QByteArray &text)
     {
-        QString base64 = "./0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
+        QString base64 = QStringLiteral("./0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ");
         QByteArray decoded;
         int k = -1;
         while (k < (text.length() - 1)) {
@@ -445,13 +441,13 @@ namespace Konversation
 
             for (int i = 0; i < 6; i++) {
                 k++;
-                v = base64.indexOf(text.at(k));
+                v = base64.indexOf(QLatin1Char(text.at(k)));
                 right |= v << (i * 6);
             }
 
             for (int i = 0; i < 6; i++) {
                 k++;
-                v = base64.indexOf(text.at(k));
+                v = base64.indexOf(QLatin1Char(text.at(k)));
                 left |= v << (i * 6);
             }
 
