@@ -239,11 +239,7 @@ public:
     QStringList formats() const override;
 
 protected:
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    QVariant retrieveData(const QString &mimeType, QVariant::Type type) const override;
-#else
     QVariant retrieveData(const QString &mimeType, QMetaType type) const override;
-#endif
 
 private:
     mutable QTextDocumentFragment fragment;
@@ -256,11 +252,7 @@ QStringList IrcViewMimeData::formats() const
     else
         return QMimeData::formats();
 }
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-QVariant IrcViewMimeData::retrieveData(const QString &mimeType, QVariant::Type type) const
-#else
 QVariant IrcViewMimeData::retrieveData(const QString &mimeType, QMetaType type) const
-#endif
 {
     if (!fragment.isEmpty())
     {
@@ -1969,7 +1961,7 @@ void IRCView::adjustUrlRanges(QList< QPair<int, int> >& urlRanges, const QString
             }
             else
             {
-                QRegularExpressionMatch match = colorRegExp.match(richtext, i, QRegularExpression::NormalMatch, QRegularExpression::AnchoredMatchOption);
+                QRegularExpressionMatch match = colorRegExp.match(richtext, i, QRegularExpression::NormalMatch, QRegularExpression::AnchorAtOffsetMatchOption);
                 if (match.hasMatch())
                 {
                     // forward to the last matched position
