@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2005 Renchi Raju <renchi@pooh.tam.uiuc.edu>
+    SPDX-FileCopyrightText: 2005 Renchi Raju <renchi@pooh.tam.uiuc.edu>
 */
 
 #ifndef IRCVIEWBOX_H
@@ -28,20 +23,21 @@ class IRCViewBox : public QWidget
 
         IRCView*   ircView() const;
 
-    public Q_SLOTS:
-
+    private Q_SLOTS:
         void slotSearch();
         void slotSearchNext();
         void slotSearchPrevious();
         void slotSearchChanged(const QString& pattern);
 
-    protected:
+    private:
         void searchNext(bool reversed = false);
 
     private:
-
         IRCView*   m_ircView;
         SearchBar* m_searchBar;
         bool       m_matchedOnce;
+
+        Q_DISABLE_COPY(IRCViewBox)
 };
+
 #endif                                            /* IRCVIEWBOX_H */
